function noop() { }
function assign(tar, src) {
    // @ts-ignore
    for (const k in src)
        tar[k] = src[k];
    return tar;
}
function run(fn) {
    return fn();
}
function blank_object() {
    return Object.create(null);
}
function run_all(fns) {
    fns.forEach(run);
}
function is_function(thing) {
    return typeof thing === 'function';
}
function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}
function is_empty(obj) {
    return Object.keys(obj).length === 0;
}
function create_slot(definition, ctx, $$scope, fn) {
    if (definition) {
        const slot_ctx = get_slot_context(definition, ctx, $$scope, fn);
        return definition[0](slot_ctx);
    }
}
function get_slot_context(definition, ctx, $$scope, fn) {
    return definition[1] && fn
        ? assign($$scope.ctx.slice(), definition[1](fn(ctx)))
        : $$scope.ctx;
}
function get_slot_changes(definition, $$scope, dirty, fn) {
    if (definition[2] && fn) {
        const lets = definition[2](fn(dirty));
        if ($$scope.dirty === undefined) {
            return lets;
        }
        if (typeof lets === 'object') {
            const merged = [];
            const len = Math.max($$scope.dirty.length, lets.length);
            for (let i = 0; i < len; i += 1) {
                merged[i] = $$scope.dirty[i] | lets[i];
            }
            return merged;
        }
        return $$scope.dirty | lets;
    }
    return $$scope.dirty;
}
function update_slot_base(slot, slot_definition, ctx, $$scope, slot_changes, get_slot_context_fn) {
    if (slot_changes) {
        const slot_context = get_slot_context(slot_definition, ctx, $$scope, get_slot_context_fn);
        slot.p(slot_context, slot_changes);
    }
}
function get_all_dirty_from_scope($$scope) {
    if ($$scope.ctx.length > 32) {
        const dirty = [];
        const length = $$scope.ctx.length / 32;
        for (let i = 0; i < length; i++) {
            dirty[i] = -1;
        }
        return dirty;
    }
    return -1;
}
function detach(node) {
    node.parentNode.removeChild(node);
}
function children(element) {
    return Array.from(element.childNodes);
}
function custom_event(type, detail, bubbles = false) {
    const e = document.createEvent('CustomEvent');
    e.initCustomEvent(type, bubbles, false, detail);
    return e;
}

let current_component;
function set_current_component(component) {
    current_component = component;
}
function get_current_component() {
    if (!current_component)
        throw new Error('Function called outside component initialization');
    return current_component;
}
function createEventDispatcher() {
    const component = get_current_component();
    return (type, detail) => {
        const callbacks = component.$$.callbacks[type];
        if (callbacks) {
            // TODO are there situations where events could be dispatched
            // in a server (non-DOM) environment?
            const event = custom_event(type, detail);
            callbacks.slice().forEach(fn => {
                fn.call(component, event);
            });
        }
    };
}

const dirty_components = [];
const binding_callbacks = [];
const render_callbacks = [];
const flush_callbacks = [];
const resolved_promise = Promise.resolve();
let update_scheduled = false;
function schedule_update() {
    if (!update_scheduled) {
        update_scheduled = true;
        resolved_promise.then(flush);
    }
}
function add_render_callback(fn) {
    render_callbacks.push(fn);
}
let flushing = false;
const seen_callbacks = new Set();
function flush() {
    if (flushing)
        return;
    flushing = true;
    do {
        // first, call beforeUpdate functions
        // and update components
        for (let i = 0; i < dirty_components.length; i += 1) {
            const component = dirty_components[i];
            set_current_component(component);
            update(component.$$);
        }
        set_current_component(null);
        dirty_components.length = 0;
        while (binding_callbacks.length)
            binding_callbacks.pop()();
        // then, once components are updated, call
        // afterUpdate functions. This may cause
        // subsequent updates...
        for (let i = 0; i < render_callbacks.length; i += 1) {
            const callback = render_callbacks[i];
            if (!seen_callbacks.has(callback)) {
                // ...so guard against infinite loops
                seen_callbacks.add(callback);
                callback();
            }
        }
        render_callbacks.length = 0;
    } while (dirty_components.length);
    while (flush_callbacks.length) {
        flush_callbacks.pop()();
    }
    update_scheduled = false;
    flushing = false;
    seen_callbacks.clear();
}
function update($$) {
    if ($$.fragment !== null) {
        $$.update();
        run_all($$.before_update);
        const dirty = $$.dirty;
        $$.dirty = [-1];
        $$.fragment && $$.fragment.p($$.ctx, dirty);
        $$.after_update.forEach(add_render_callback);
    }
}
const outroing = new Set();
let outros;
function transition_in(block, local) {
    if (block && block.i) {
        outroing.delete(block);
        block.i(local);
    }
}
function transition_out(block, local, detach, callback) {
    if (block && block.o) {
        if (outroing.has(block))
            return;
        outroing.add(block);
        outros.c.push(() => {
            outroing.delete(block);
            if (callback) {
                if (detach)
                    block.d(1);
                callback();
            }
        });
        block.o(local);
    }
}
function mount_component(component, target, anchor, customElement) {
    const { fragment, on_mount, on_destroy, after_update } = component.$$;
    fragment && fragment.m(target, anchor);
    if (!customElement) {
        // onMount happens before the initial afterUpdate
        add_render_callback(() => {
            const new_on_destroy = on_mount.map(run).filter(is_function);
            if (on_destroy) {
                on_destroy.push(...new_on_destroy);
            }
            else {
                // Edge case - component was destroyed immediately,
                // most likely as a result of a binding initialising
                run_all(new_on_destroy);
            }
            component.$$.on_mount = [];
        });
    }
    after_update.forEach(add_render_callback);
}
function destroy_component(component, detaching) {
    const $$ = component.$$;
    if ($$.fragment !== null) {
        run_all($$.on_destroy);
        $$.fragment && $$.fragment.d(detaching);
        // TODO null out other refs, including component.$$ (but need to
        // preserve final state?)
        $$.on_destroy = $$.fragment = null;
        $$.ctx = [];
    }
}
function make_dirty(component, i) {
    if (component.$$.dirty[0] === -1) {
        dirty_components.push(component);
        schedule_update();
        component.$$.dirty.fill(0);
    }
    component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
}
function init(component, options, instance, create_fragment, not_equal, props, append_styles, dirty = [-1]) {
    const parent_component = current_component;
    set_current_component(component);
    const $$ = component.$$ = {
        fragment: null,
        ctx: null,
        // state
        props,
        update: noop,
        not_equal,
        bound: blank_object(),
        // lifecycle
        on_mount: [],
        on_destroy: [],
        on_disconnect: [],
        before_update: [],
        after_update: [],
        context: new Map(options.context || (parent_component ? parent_component.$$.context : [])),
        // everything else
        callbacks: blank_object(),
        dirty,
        skip_bound: false,
        root: options.target || parent_component.$$.root
    };
    append_styles && append_styles($$.root);
    let ready = false;
    $$.ctx = instance
        ? instance(component, options.props || {}, (i, ret, ...rest) => {
            const value = rest.length ? rest[0] : ret;
            if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                if (!$$.skip_bound && $$.bound[i])
                    $$.bound[i](value);
                if (ready)
                    make_dirty(component, i);
            }
            return ret;
        })
        : [];
    $$.update();
    ready = true;
    run_all($$.before_update);
    // `false` as a special case of no DOM component
    $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
    if (options.target) {
        if (options.hydrate) {
            const nodes = children(options.target);
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.l(nodes);
            nodes.forEach(detach);
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.c();
        }
        if (options.intro)
            transition_in(component.$$.fragment);
        mount_component(component, options.target, options.anchor, options.customElement);
        flush();
    }
    set_current_component(parent_component);
}
/**
 * Base class for Svelte components. Used when dev=false.
 */
class SvelteComponent {
    $destroy() {
        destroy_component(this, 1);
        this.$destroy = noop;
    }
    $on(type, callback) {
        const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
        callbacks.push(callback);
        return () => {
            const index = callbacks.indexOf(callback);
            if (index !== -1)
                callbacks.splice(index, 1);
        };
    }
    $set($$props) {
        if (this.$$set && !is_empty($$props)) {
            this.$$.skip_bound = true;
            this.$$set($$props);
            this.$$.skip_bound = false;
        }
    }
}

var justDiff = {
  diff: diff,
  jsonPatchPathConverter: jsonPatchPathConverter,
};

/*
  const obj1 = {a: 4, b: 5};
  const obj2 = {a: 3, b: 5};
  const obj3 = {a: 4, c: 5};

  diff(obj1, obj2);
  [
    { "op": "replace", "path": ['a'], "value": 3 }
  ]

  diff(obj2, obj3);
  [
    { "op": "remove", "path": ['b'] },
    { "op": "replace", "path": ['a'], "value": 4 }
    { "op": "add", "path": ['c'], "value": 5 }
  ]

  // using converter to generate jsPatch standard paths
  // see http://jsonpatch.com
  import {diff, jsonPatchPathConverter} from 'just-diff'
  diff(obj1, obj2, jsonPatchPathConverter);
  [
    { "op": "replace", "path": '/a', "value": 3 }
  ]

  diff(obj2, obj3, jsonPatchPathConverter);
  [
    { "op": "remove", "path": '/b' },
    { "op": "replace", "path": '/a', "value": 4 }
    { "op": "add", "path": '/c', "value": 5 }
  ]

  // arrays
  const obj4 = {a: 4, b: [1, 2, 3]};
  const obj5 = {a: 3, b: [1, 2, 4]};
  const obj6 = {a: 3, b: [1, 2, 4, 5]};

  diff(obj4, obj5);
  [
    { "op": "replace", "path": ['a'], "value": 3 }
    { "op": "replace", "path": ['b', 2], "value": 4 }
  ]

  diff(obj5, obj6);
  [
    { "op": "add", "path": ['b', 3], "value": 5 }
  ]

  // nested paths
  const obj7 = {a: 4, b: {c: 3}};
  const obj8 = {a: 4, b: {c: 4}};
  const obj9 = {a: 5, b: {d: 4}};

  diff(obj7, obj8);
  [
    { "op": "replace", "path": ['b', 'c'], "value": 4 }
  ]

  diff(obj8, obj9);
  [
    { "op": "replace", "path": ['a'], "value": 5 }
    { "op": "remove", "path": ['b', 'c']}
    { "op": "add", "path": ['b', 'd'], "value": 4 }
  ]
*/

function diff(obj1, obj2, pathConverter) {
  if (!obj1 || typeof obj1 != 'object' || !obj2 || typeof obj2 != 'object') {
    throw new Error('both arguments must be objects or arrays');
  }

  pathConverter ||
    (pathConverter = function(arr) {
      return arr;
    });

  function getDiff(obj1, obj2, basePath, diffs) {
    var obj1Keys = Object.keys(obj1);
    var obj1KeysLength = obj1Keys.length;
    var obj2Keys = Object.keys(obj2);
    var obj2KeysLength = obj2Keys.length;
    var path;

    for (var i = 0; i < obj1KeysLength; i++) {
      var key = Array.isArray(obj1) ? Number(obj1Keys[i]) : obj1Keys[i];
      if (!(key in obj2)) {
        path = basePath.concat(key);
        diffs.remove.push({
          op: 'remove',
          path: pathConverter(path),
        });
      }
    }

    for (var i = 0; i < obj2KeysLength; i++) {
      var key = Array.isArray(obj2) ? Number(obj2Keys[i]) : obj2Keys[i];
      var obj1AtKey = obj1[key];
      var obj2AtKey = obj2[key];
      if (!(key in obj1)) {
        path = basePath.concat(key);
        var obj2Value = obj2[key];
        diffs.add.push({
          op: 'add',
          path: pathConverter(path),
          value: obj2Value,
        });
      } else if (obj1AtKey !== obj2AtKey) {
        if (
          Object(obj1AtKey) !== obj1AtKey ||
          Object(obj2AtKey) !== obj2AtKey
        ) {
          path = pushReplace(path, basePath, key, diffs, pathConverter, obj2);
        } else {
          if (
            !Object.keys(obj1AtKey).length &&
            !Object.keys(obj2AtKey).length &&
            String(obj1AtKey) != String(obj2AtKey)
          ) {
            path = pushReplace(path, basePath, key, diffs, pathConverter, obj2);
          } else {
            getDiff(obj1[key], obj2[key], basePath.concat(key), diffs);
          }
        }
      }
    }

    return diffs.remove
      .reverse()
      .concat(diffs.replace)
      .concat(diffs.add);
  }
  return getDiff(obj1, obj2, [], {remove: [], replace: [], add: []});
}

function pushReplace(path, basePath, key, diffs, pathConverter, obj2) {
  path = basePath.concat(key);
  diffs.replace.push({
    op: 'replace',
    path: pathConverter(path),
    value: obj2[key],
  });
  return path;
}

function jsonPatchPathConverter(arrayPath) {
  return [''].concat(arrayPath).join('/');
}

/* src/Form.svelte generated by Svelte v3.43.0 */
const get_default_slot_changes$1 = dirty => ({ errors: dirty & /*errors*/ 1 });

const get_default_slot_context$1 = ctx => ({
	create: /*create*/ ctx[2],
	remove: /*remove*/ ctx[1],
	errors: /*errors*/ ctx[0]
});

function create_fragment$1(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[8].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[7], get_default_slot_context$1);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope, errors*/ 129)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[7],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[7])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[7], dirty, get_default_slot_changes$1),
						get_default_slot_context$1
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function instance$1($$self, $$props, $$invalidate) {
	let errors;
	let { $$slots: slots = {}, $$scope } = $$props;
	const { diff } = justDiff;
	let { form } = $$props;
	let { startingCount = 0 } = $$props;
	let { prefix = 'GID' } = $$props;
	let { suffix = '' } = $$props;
	let count = startingCount;

	const makeDiff = (form, id) => {
		form.changes[id] = diff(form.original[id] || {}, form.data[id] || {});
		if (!form.changes[id].length) delete form.changes[id];
		if (Object.keys(form.changes).length) form.state = 'unsaved'; else form.state = 'unchanged';
	};

	const dispatch = createEventDispatcher();

	const remove = ({ id, type }) => {
		delete form.data[id];
		makeDiff(form, id);

		for (let resourceId in form.data) {
			let touched;
			let resource = form.data[resourceId];

			for (let relName of Object.keys(resource.relationships || {})) {
				const rel = resource.relationships[relName];

				if (Array.isArray(rel.data)) {
					let filtered = rel.data.filter(r => r.id !== id || r.type !== type);

					if (filtered.length !== rel.data.length) {
						$$invalidate(3, form.data[resourceId].relationships[relName].data = filtered, form);
						if (!rel.data.length) delete form.data[resourceId].relationships[relName].data;
						touched = true;
					}
				} else if (rel?.data?.id === id && rel?.data?.type === type) {
					delete form.data[resourceId].relationships[relName].data;
					touched = true;
				}

				if (!rel.data) {
					delete form.data[resourceId].relationships[relName];
					touched = true;
				}
			}

			if (!Object.keys(resource.relationships || {}).length) {
				delete form.data[resourceId].relationships;
				touched = true;
			}

			if (touched) makeDiff(form, resourceId);
		}

		dispatch('remove', { id, type });
	};

	const create = ({ relId, relName, isArray, type }) => {
		let id = `${prefix}${++count}${suffix}`;
		$$invalidate(3, form.data[id] = { type, id }, form);
		makeDiff(form, id);
		if (!form.data[relId].relationships) $$invalidate(3, form.data[relId].relationships = {}, form);
		if (!form.data[relId].relationships[relName]) $$invalidate(3, form.data[relId].relationships[relName] = {}, form);

		if (isArray) {
			let data = form.data[relId].relationships[relName].data || [];
			data.push({ type, id });
			$$invalidate(3, form.data[relId].relationships[relName].data = data, form);
		} else {
			$$invalidate(3, form.data[relId].relationships[relName].date = { type, id }, form);
		}

		makeDiff(form, relId);
		dispatch('create', { relId, relName, isArray, type });
	};

	$$self.$$set = $$props => {
		if ('form' in $$props) $$invalidate(3, form = $$props.form);
		if ('startingCount' in $$props) $$invalidate(4, startingCount = $$props.startingCount);
		if ('prefix' in $$props) $$invalidate(5, prefix = $$props.prefix);
		if ('suffix' in $$props) $$invalidate(6, suffix = $$props.suffix);
		if ('$$scope' in $$props) $$invalidate(7, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*form*/ 8) {
			$$invalidate(0, errors = form?.errors?.other || []);
		}
	};

	return [errors, remove, create, form, startingCount, prefix, suffix, $$scope, slots];
}

class Form extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$1, create_fragment$1, safe_not_equal, {
			form: 3,
			startingCount: 4,
			prefix: 5,
			suffix: 6
		});
	}
}

function dlv(t,e,l,n,r){for(e=e.split?e.split("."):e,n=0;n<e.length;n++)t=t?t[e[n]]:r;return t===r?l:t}

/*

Note on escaping order, from RFC6901:

> Evaluation of each reference token begins by decoding any escaped
> character sequence.  This is performed by first transforming any
> occurrence of the sequence '~1' to '/', and then transforming any
> occurrence of the sequence '~0' to '~'.  By performing the
> substitutions in this order, an implementation avoids the error of
> turning '~01' first into '~1' and then into '/', which would be
> incorrect (the string '~01' correctly becomes '~1' after
> transformation).

*/

/**
 * Convert a JSON Pointer into a list of unescaped tokens, e.g. `/foo/bar~1biz` to `['foo','bar/biz']`.
 * @type {import("../index").toTokens}
 */
const toTokens = function (path) {
	[ , ...path ] = path.split('/');
	let segments = [];
	for (let segment of path) {
		segments.push(segment.replaceAll('~1', '/').replaceAll('~0', '~'));
	}
	return segments
};

/**
 * @param {String|Array<String>} input
 * @returns {Array<String>}
 */
const makeConsistent = input => input.split ? toTokens(input) : input;

/**
 * Access a property by JSON Pointer, or by an array of property tokens.
 * @type {import("../index").get}
 */
const get = function (obj, path) {
	return dlv(obj, makeConsistent(path))
};

var justDebounceIt = debounce;

function debounce(fn, wait, callFirst) {
  var timeout = null;
  var debouncedFn = null;

  var clear = function() {
    if (timeout) {
      clearTimeout(timeout);

      debouncedFn = null;
      timeout = null;
    }
  };

  var flush = function() {
    var call = debouncedFn;
    clear();

    if (call) {
      call();
    }
  };

  var debounceWrapper = function() {
    if (!wait) {
      return fn.apply(this, arguments);
    }

    var context = this;
    var args = arguments;
    var callNow = callFirst && !timeout;
    clear();

    debouncedFn = function() {
      fn.apply(context, args);
    };

    timeout = setTimeout(function() {
      timeout = null;

      if (!callNow) {
        var call = debouncedFn;
        debouncedFn = null;

        return call();
      }
    }, wait);

    if (callNow) {
      return debouncedFn();
    }
  };

  debounceWrapper.cancel = clear;
  debounceWrapper.flush = flush;

  return debounceWrapper;
}

/* src/Field.svelte generated by Svelte v3.43.0 */

const get_default_slot_changes = dirty => ({
	value: dirty & /*value*/ 4,
	errors: dirty & /*errors*/ 2
});

const get_default_slot_context = ctx => ({
	value: /*value*/ ctx[2],
	set: /*set*/ ctx[0],
	errors: /*errors*/ ctx[1]
});

function create_fragment(ctx) {
	let current;
	const default_slot_template = /*#slots*/ ctx[9].default;
	const default_slot = create_slot(default_slot_template, ctx, /*$$scope*/ ctx[8], get_default_slot_context);

	return {
		c() {
			if (default_slot) default_slot.c();
		},
		m(target, anchor) {
			if (default_slot) {
				default_slot.m(target, anchor);
			}

			current = true;
		},
		p(ctx, [dirty]) {
			if (default_slot) {
				if (default_slot.p && (!current || dirty & /*$$scope, value, errors*/ 262)) {
					update_slot_base(
						default_slot,
						default_slot_template,
						ctx,
						/*$$scope*/ ctx[8],
						!current
						? get_all_dirty_from_scope(/*$$scope*/ ctx[8])
						: get_slot_changes(default_slot_template, /*$$scope*/ ctx[8], dirty, get_default_slot_changes),
						get_default_slot_context
					);
				}
			}
		},
		i(local) {
			if (current) return;
			transition_in(default_slot, local);
			current = true;
		},
		o(local) {
			transition_out(default_slot, local);
			current = false;
		},
		d(detaching) {
			if (default_slot) default_slot.d(detaching);
		}
	};
}

function instance($$self, $$props, $$invalidate) {
	let tokens;
	let value;
	let errors;
	let { $$slots: slots = {}, $$scope } = $$props;
	const { diff } = justDiff;
	let { form } = $$props;
	let { id } = $$props;
	let { keypath } = $$props;
	let { debounceMillis } = $$props;

	/*
Because the diff calculation is expensive, we debounce so that e.g. entering text
rapidly won't cause a sudden pile of blocking diff calculations to slow the UI.
 */
	const dispatch = createEventDispatcher();

	const change = justDebounceIt(
		updatedValue => {
			$$invalidate(3, form.changes[id] = diff(form.original[id] || {}, form.data[id] || {}), form);
			if (!form.changes[id].length) delete form.changes[id];
			if (Object.keys(form.changes).length) $$invalidate(3, form.state = 'changed', form); else $$invalidate(3, form.state = 'unchanged', form);
			dispatch('change', { id, keypath: tokens, value: updatedValue });
		},
		debounceMillis || 15,
		true
	);

	const set = v => {
		let [k1, k2, k3, k4, k5, k6] = tokens;
		let l = tokens.length;

		/*
The Svelte compiler looks for reassignment as the method to detect whether a
function inside a component is modifying a bound value. Because of this, the
reassignment process can't use the normal shortcut found in e.g. @lukeed/dset,
thus the following method which is limited in depth.
 */
		l > 0 && (form.data[id][k1] ?? $$invalidate(3, form.data[id][k1] = {}, form));

		l > 1 && (form.data[id][k1][k2] ?? $$invalidate(3, form.data[id][k1][k2] = {}, form));
		l > 2 && (form.data[id][k1][k2][k3] ?? $$invalidate(3, form.data[id][k1][k2][k3] = {}, form));
		l > 3 && (form.data[id][k1][k2][k3][k4] ?? $$invalidate(3, form.data[id][k1][k2][k3][k4] = {}, form));
		l > 4 && (form.data[id][k1][k2][k3][k4][k5] ?? $$invalidate(3, form.data[id][k1][k2][k3][k4][k5] = {}, form));
		l > 5 && (form.data[id][k1][k2][k3][k4][k5][k6] ?? $$invalidate(3, form.data[id][k1][k2][k3][k4][k5][k6] = {}, form));
		if (l === 1) $$invalidate(3, form.data[id][k1] = v, form);
		if (l === 2) $$invalidate(3, form.data[id][k1][k2] = v, form);
		if (l === 3) $$invalidate(3, form.data[id][k1][k2][k3] = v, form);
		if (l === 4) $$invalidate(3, form.data[id][k1][k2][k3][k4] = v, form);
		if (l === 5) $$invalidate(3, form.data[id][k1][k2][k3][k4][k5] = v, form);
		if (l === 6) $$invalidate(3, form.data[id][k1][k2][k3][k4][k5][k6] = v, form);
		change(v);
	};

	$$self.$$set = $$props => {
		if ('form' in $$props) $$invalidate(3, form = $$props.form);
		if ('id' in $$props) $$invalidate(4, id = $$props.id);
		if ('keypath' in $$props) $$invalidate(5, keypath = $$props.keypath);
		if ('debounceMillis' in $$props) $$invalidate(6, debounceMillis = $$props.debounceMillis);
		if ('$$scope' in $$props) $$invalidate(8, $$scope = $$props.$$scope);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*keypath*/ 32) {
			$$invalidate(7, tokens = keypath.split ? toTokens(keypath) : keypath);
		}

		if ($$self.$$.dirty & /*form, id, tokens*/ 152) {
			$$invalidate(2, value = get(form.data[id], tokens) || '');
		}

		if ($$self.$$.dirty & /*form, id, tokens*/ 152) {
			$$invalidate(1, errors = get(form, ['errors', 'mapped', id, ...tokens]) || []);
		}
	};

	return [set, errors, value, form, id, keypath, debounceMillis, tokens, $$scope, slots];
}

class Field extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance, create_fragment, safe_not_equal, {
			form: 3,
			id: 4,
			keypath: 5,
			debounceMillis: 6,
			set: 0
		});
	}

	get set() {
		return this.$$.ctx[0];
	}
}

export { Field, Form };
